@@ -123,6 +123,10 @@ class ClClientAction(Action):
           'method':'Client.cAddCacheUsersFromSystem()',
           'depend':Tasks.failed_all('mount_remote')
          },
+         # удалить службу client из автозапуска
+         {'name':'undomain:noautorun_client',
+          'method':'Client.delDaemonAutostart("client")'
+         },
          # добавить службу client в автозапуск
          {'name':'domain:autorun_client',
           'method':'Client.addDaemonAutostart("client")'
